@@ -2,17 +2,21 @@
 #' @description \code{bdpsurvival} is used to estimate the survival probability
 #'   (single arm trial; OPC) or hazard ratio (two-arm trial; RCT) for
 #'   right-censored data using the survival analysis implementation of the
-#'   Bayesian discount prior.
+#'   Bayesian discount prior. This code is modeled after
+#'   the methodologies developed in Haddad et al. (2017).
 #' @param formula an object of class "formula." Must have a survival object on
 #'   the left side and exactly two inputs on the right side: treatment and
 #'   historical. See "Details" for more information.
 #' @param data data frame. A data frame with columns 'time', 'status',
 #'   'treatment', and historical.' See "Details" for required structure.
 #' @param breaks vector. Breaks (interval starts) used to compose the breaks of the
-#'   piecewise exponential model. Do not include zero.
-#' @param a0 scalar. Prior value for the gamma shape. Default is 1.
-#' @param b0 scalar. Prior value for the gamma rate. Default is 1.
-#' @param surv_time scalar. Survival time of interest for computing the the
+#'   piecewise exponential model. Do not include zero. Default breaks are the
+#'   quantiles of the input times.
+#' @param a0 scalar. Prior value for the gamma shape of the piecewise
+#'   exponential hazards. Default is 1.
+#' @param b0 scalar. Prior value for the gamma rate of the piecewise
+#'   exponential hazards. Default is 1.
+#' @param surv_time scalar. Survival time of interest for computing the
 #'   probability of survival for a single arm (OPC) trial. Default is
 #'   overall, i.e., current+historical, median survival time.
 #' @param alpha_max scalar. Maximum weight the discount function can apply.
@@ -20,8 +24,7 @@
 #'   where the first value is used to weight the historical treatment group and
 #'   the second value is used to weight the historical control group.
 #' @param fix_alpha logical. Fix alpha at alpha_max? Default value is FALSE.
-#' @param number_mcmc scalar. Number of Markov Chain Monte Carlo (MCMC)
-#'   simulations. Default is 10000.
+#' @param number_mcmc scalar. Number of Monte Carlo simulations. Default is 10000.
 #' @param weibull_shape scalar. Shape parameter of the Weibull discount function
 #'   used to compute alpha, the weight parameter of the historical data. Default
 #'   value is 3. For a two-arm trial, users may specify a vector of two values
@@ -46,31 +49,43 @@
 #'   Disagreement between current and historical data is determined by stochastically
 #'   comparing the respective posterior distributions under noninformative priors.
 #'   With a single arm survival data analysis, the comparison is the
-#'   proability (\code{p}) that the current survial is less than the historical
-#'   survival. The comparison metric \code{p} is then
+#'   probability (\code{p}) that the current survival is less than the historical
+#'   survival. For a two-arm survival data, analysis the comparison is the
+#'   probability that the hazard ratio comparing treatment and control is
+#'   different from zero. The comparison metric \code{p} is then
 #'   input into the Weibull discount function and the final strength of the
 #'   historical data is returned (alpha).
 #'
-#' In the second stage, posterior estimation is performed where the discount
+#'   In the second stage, posterior estimation is performed where the discount
 #'   function parameter, \code{alpha}, is used as a fixed value for all posterior
 #'   estimation procedures.
 #'
-#'  To carry out a single arm (OPC) analysis, data for the current and
-#'  historical treatments are specified in a dataframe. The dataframe must have
-#'  columns with names 'time', 'status', 'treatment', and 'historical.' Column
-#'  'time' is the survival (censor) time of the event and 'status' is the
-#'  event indicator. The column 'treatment' is used to indicate which observations
-#'  are in the treatment and control group. A value of 1 indicates that the
-#'  observation is in the treatment group. The column 'historical' indicates
-#'  whether the observation is from the historical data (1) or current data (0).
-#'  The results are then based on the posterior distribution of the current data
-#'  augmented by the historical data.
+#'   To carry out a single arm (OPC) analysis, data for the current and
+#'   historical treatments are specified in a data frame. The data frame must have
+#'   columns with names 'time', 'status', 'treatment', and 'historical.' Column
+#'   'time' is the survival (censor) time of the event and 'status' is the
+#'   event indicator. The column 'treatment' is used to indicate which observations
+#'   are in the treatment and control group. A value of 1 indicates that the
+#'   observation is in the treatment group. The column 'historical' indicates
+#'   whether the observation is from the historical data (1) or current data (0).
+#'   The results are then based on the posterior probability of survival at
+#'   \code{surv_time} for the current data augmented by the historical data.
 #'
-#'  Two-arm (RCT) analyses are not available with this release.
+#'   Two-arm (RCT) analyses are specified similarly to a single arm trial. Again
+#'   the input data frame must have columns with names 'time', 'status',
+#'   'treatment', and 'historical.' Column 'time' is the survival (censor) time
+#'   of the event and 'status' is the event indicator. Now, the 'treatment'
+#'   column must use 0 to indicate the control group. The current data are
+#'   augmented by historical data (if present) and the results are then based
+#'   on the posterior distribution of the hazard ratio between the treatment
+#'   and control groups.
+#'
+#'   For more details, see the \code{bdpsurvival} vignette: \cr
+#'   \code{vignette("bdpsurvival-vignette", package="bayesDP")}
 #'
 #' @return \code{bdpsurvival} returns an object of class "bdpsurvival".
-#' The functions \code{summary} and \code{print} are used to obtain and
-#' print a summary of the results, including user inputs. The \code{plot}
+#' The functions \code{\link[=summary,bdpsurvival-method]{summary}} and \code{\link[=print,bdpsurvival-method]{print}} are used to obtain and
+#' print a summary of the results, including user inputs. The \code{\link[=plot,bdpsurvival-method]{plot}}
 #' function displays visual outputs as well.
 #'
 #' An object of class "\code{bdpsurvival}" is a list containing at least
@@ -84,67 +99,110 @@
 #'      \item{\code{p_hat}}{
 #'        numeric. The posterior probability of the stochastic comparison
 #'        between the current and historical data.}
-#'      \item{\code{posterior}}{
-#'        list. Entries contain \code{cdf}, a vector of the posterior cdf of the
-#'        piecewise exponentialdistribution; \code{surv_time_posterior}, a
-#'        vector with the posterior of the survival probability; and
-#'        \code{posterior}, a matrix of the posteriors of each of the piecewise
-#'        hazards.}
-#'      \item{\code{posterior_flat}}{
-#'        matrix. The distributions of the current treatment group piecewise
-#'        hazard rates.}
-#'      \item{\code{prior}}{
-#'        matrix. The distributions of the historical treatment group piecewise
-#'        hazard rates.}
-#'   }
-#'  \item{\code{f1}}{
-#'    list. Entries contain values related to the posterior effect:}
-#'    \itemize{
-#'      \item{\code{density_post_treatment}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the treatment group posterior.}
-#'      \item{\code{density_flat_treatment}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the treatment group "flat" distribution.}
-#'      \item{\code{density_prior_treatment}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the treatment group prior.}
-#'      \item{\code{treatmentpost}}{
-#'        vector. Used internally to plot the posterior distribution of the
-#'        survival probability.}
+#'      \item{\code{posterior_survival}}{
+#'        vector. If one-arm trial, a vector of length \code{number_mcmc}
+#'        containing the posterior probability draws of survival at
+#'        \code{surv_time}.}
+#'      \item{\code{posterior_flat_survival}}{
+#'        vector. If one-arm trial, a vector of length \code{number_mcmc}
+#'        containing the probability draws of survival at \code{surv_time}
+#'        for the current treatment not augmented by historical treatment.}
+#'      \item{\code{prior_survival}}{
+#'        vector. If one-arm trial, a vector of length \code{number_mcmc}
+#'        containing the probability draws of survival at \code{surv_time}
+#'        for the historical treatment.}
+#'      \item{\code{posterior_hazard}}{
+#'        matrix. A matrix with \code{number_mcmc} rows and \code{length(breaks)}
+#'        columns containing the posterior draws of the piecewise hazards
+#'        for each interval break point.}
+#'      \item{\code{posterior_flat_hazard}}{
+#'        matrix. A matrix with \code{number_mcmc} rows and \code{length(breaks)}
+#'        columns containing the draws of piecewise hazards for each interval
+#'        break point for current treatment not augmented by historical treatment.}
+#'      \item{\code{prior_hazard}}{
+#'        matrix. A matrix with \code{number_mcmc} rows and \code{length(breaks)}
+#'        columns containing the draws of piecewise hazards for each interval break point
+#'        for historical treatment.}
 #'   }
+#'  \item{\code{posterior_control}}{
+#'    list. If two-arm trial, contains values related to the control group
+#'    analagous to the \code{posterior_treatment} output.}
 #'  \item{\code{args1}}{
 #'    list. Entries contain user inputs. In addition, the following elements
 #'    are ouput:}
 #'    \itemize{
-#'      \item{\code{S_t} and \code{S0_t}}{
-#'        survival objects. Used internally pass survival data between
+#'      \item{\code{S_t}, \code{S_c}, \code{S0_t}, \code{S0_c}}{
+#'        survival objects. Used internally to pass survival data between
 #'        functions.}
+#'      \item{\code{arm2}}{
+#'        logical. Used internally to indicate one-arm or two-arm analysis.}
 #'   }
 #' }
 #'
+#' @seealso \code{\link[=summary,bdpsurvival-method]{summary}},
+#'   \code{\link[=print,bdpsurvival-method]{print}},
+#'   and \code{\link[=plot,bdpsurvival-method]{plot}} for details of each of the
+#'   supported methods.
+#'
+#' @references
+#' Haddad, T., Himes, A., Thompson, L., Irony, T., Nair, R. MDIC Computer
+#'   Modeling and Simulation working group.(2017) Incorporation of stochastic
+#'   engineering models as prior information in Bayesian medical device trials.
+#'   \emph{Journal of Biopharmaceutical Statistics}, 1-15.
+#'
 #' @examples
-#' # One-arm trial (OPC) example
+#' # One-arm trial (OPC) example - survival probability at 5 years
 #' # Simulate survival data for a single arm (OPC) trial
 #' time   <- c(rexp(50, rate=1/20), rexp(50, rate=1/10))
 #' status <- c(rexp(50, rate=1/30), rexp(50, rate=1/30))
 #' status <- ifelse(time < status, 1, 0)
 #'
-#' # Collect data into a dataframe
+#' # Collect data into a data frame
 #' example_surv_1arm <- data.frame(status     = status,
 #'                                 time       = time,
 #'                                 historical = c(rep(1,50),rep(0,50)),
 #'                                 treatment  = 1)
 #'
-#' fitSurv <- bdpsurvival(Surv(time, status) ~ historical + treatment,
-#'                        data = example_surv_1arm)
+#' fit1 <- bdpsurvival(Surv(time, status) ~ historical + treatment,
+#'                     data = example_surv_1arm,
+#'                     surv_time = 5)
 #'
-#' summary(fitSurv)
+#' print(fit1)
+#' \dontrun{
+#' plot(fit1)
+#' }
+#'
+#' # Two-arm trial (OPC) example
+#' # Simulate survival data for a two-arm trial
+#' time   <- c(rexp(50, rate=1/20), # Current treatment
+#'             rexp(50, rate=1/10), # Current control
+#'             rexp(50, rate=1/30), # Historical treatment
+#'             rexp(50, rate=1/5))  # Historical control
+#' status <- rexp(200, rate=1/40)
+#' status <- ifelse(time < status, 1, 0)
+#'
+#' # Collect data into a data frame
+#' example_surv_2arm <- data.frame(status     = status,
+#'                                 time       = time,
+#'                                 historical = c(rep(0,100),rep(1,100)),
+#'                                 treatment  = c(rep(1,50),rep(0,50),rep(1,50),rep(0,50)))
+#'
+#' fit2 <- bdpsurvival(Surv(time, status) ~ historical + treatment,
+#'                        data = example_surv_2arm)
+#'
+#' summary(fit2)
+#'
+#' ### Fix alpha at 1
+#' fit2_1 <- bdpsurvival(Surv(time, status) ~ historical + treatment,
+#'                       data = example_surv_2arm,
+#'                       fix_alpha = TRUE)
+#'
+#' summary(fit2_1)
 #'
 #'
 #' @rdname bdpsurvival
 #' @import methods
-#' @importFrom stats density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
+#' @importFrom stats sd density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
 #' @importFrom survival Surv survSplit
 #' @aliases bdpsurvival,ANY-method
 #' @export bdpsurvival
@@ -182,7 +240,7 @@ setMethod("bdpsurvival",
            weibull_shape = 3,
            two_side      = TRUE){
 
-  ### Check dataframe and ensure it has the correct column names
+  ### Check data frame and ensure it has the correct column names
   namesData <- tolower(names(data))
   namesDiff <- setdiff(c("status", "time", "historical", "treatment"), namesData)
   if(length(namesDiff)>0){
@@ -190,11 +248,11 @@ setMethod("bdpsurvival",
     if(nDiff == 1){
       errorMsg <- paste0("Column ",
                          namesDiff,
-                         " is missing from the input dataframe.")
+                         " is missing from the input data frame.")
       stop(errorMsg)
     } else if(nDiff>1){
       errorNames <- paste0(namesDiff, collapse = ", ")
-      errorMsg <- paste0("Columns are missing from input dataframe: ",
+      errorMsg <- paste0("Columns are missing from input data frame: ",
                          errorNames)
       stop(errorMsg)
     }
@@ -235,7 +293,7 @@ setMethod("bdpsurvival",
   ### If zero is present in breaks, remove and give warning
   if(any(breaks==0)){
     breaks <- breaks[!(breaks==0)]
-    warning("Breaks vector includeded 0. The zero value was removed.")
+    warning("Breaks vector included 0. The zero value was removed.")
   }
 
 
@@ -275,7 +333,7 @@ setMethod("bdpsurvival",
     arm2 <- TRUE
   }
 
-  if(arm2) stop("Two arm trials are not currently supported.")
+  #if(arm2) stop("Two arm trials are not currently supported.")
 
   ### If surv_time is null, replace with median time
   if(is.null(surv_time) & !arm2){
@@ -328,12 +386,6 @@ setMethod("bdpsurvival",
   }
 
 
-  f1 <- final_survival(posterior_treatment = posterior_treatment,
-                       posterior_control   = posterior_control,
-                       arm2                = arm2,
-                       surv_time           = surv_time,
-                       breaks              = breaks)
-
   args1 <- list(S_t           = S_t,
                 S_c           = S_c,
                 S0_t          = S0_t,
@@ -353,7 +405,6 @@ setMethod("bdpsurvival",
 
   me <- list(posterior_treatment = posterior_treatment,
              posterior_control   = posterior_control,
-             f1                  = f1,
              args1               = args1)
 
   class(me) <- "bdpsurvival"
@@ -384,7 +435,7 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
 
   if(!is.null(S0)){
     S0_int  <- levels(S0$interval)
-    n0Int   <- length(S0_int)
+    nInt    <- length(S0_int)
   }
 
   interval <- NULL
@@ -398,9 +449,14 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
   if(!is.null(S) & !is.null(S0)){
     ### Compute posterior of interval hazards
     a_post  <- b_post  <- numeric(nInt)
-    a_post0 <- b_post0 <- numeric(n0Int)
+    a_post0 <- b_post0 <- numeric(nInt)
+
+    if(!is.null(S)){
+      posterior_flat_hazard <- prior_hazard <- matrix(NA, number_mcmc, nInt)
+    } else{
+      posterior_flat_hazard <- prior_hazard <- matrix(NA, number_mcmc, nInt)
+    }
 
-    posterior_flat_hazard <- prior_hazard <- matrix(NA, number_mcmc, nInt)
 
     ### Compute posterior values
     for(i in 1:nInt){
@@ -431,13 +487,13 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
     }
   } else if(is.null(S) & !is.null(S0)) {
     ### Compute posterior of interval hazards
-    a_post0 <- b_post0 <- numeric(n0Int)
+    a_post0 <- b_post0 <- numeric(nInt)
 
     prior_hazard          <- matrix(NA, number_mcmc, nInt)
     posterior_flat_hazard <- NULL
 
     ### Compute posterior values
-    for(i in 1:n0Int){
+    for(i in 1:nInt){
       a_post0[i] <- a0 + sum(subset(S0, interval==S0_int[i])$status)
       b_post0[i] <- b0 + sum(subset(S0, interval==S0_int[i])$exposure)
 
@@ -491,16 +547,16 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
     prior_survival           <- 1 - ppexp(q=surv_time, x=prior_hazard, cuts = c(0,breaks))
 
     ### Compute probability that survival is greater for current vs historical
-    p_test <- mean(posterior_flat_survival > prior_survival)   # higher is better survival
+    p_hat <- mean(posterior_flat_survival > prior_survival)   # higher is better survival
 
     if(fix_alpha){
       alpha_discount <- alpha_max
     } else{
       if (!two_side) {
-        alpha_discount <- pweibull(p_test, shape=weibull_shape, scale=weibull_scale)*alpha_max
+        alpha_discount <- pweibull(p_hat, shape=weibull_shape, scale=weibull_scale)*alpha_max
       } else if (two_side){
-        p_test1    <- ifelse(p_test > 0.5, 1 - p_test, p_test)
-        alpha_discount <- pweibull(p_test1, shape=weibull_shape, scale=weibull_scale)*alpha_max
+        p_hat    <- ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
+        alpha_discount <- pweibull(p_hat, shape=weibull_shape, scale=weibull_scale)*alpha_max
       }
     }
   } else{
@@ -510,16 +566,16 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
     V0     <- 1/apply(R0,2,var)
     logHR0 <- R0%*%V0/sum(V0)    #weighted average  of SE^2
 
-    p_test <- mean(logHR0 > 0)   #larger is higher failure
+    p_hat <- mean(logHR0 > 0)   #larger is higher failure
 
     if(fix_alpha){
       alpha_discount <- alpha_max
     } else{
       if (!two_side) {
-        alpha_discount <- pweibull(p_test, shape=weibull_shape, scale=weibull_scale)*alpha_max
+        alpha_discount <- pweibull(p_hat, shape=weibull_shape, scale=weibull_scale)*alpha_max
       } else if (two_side){
-        p_test1    <- ifelse(p_test > 0.5, 1 - p_test, p_test)
-        alpha_discount <- pweibull(p_test1, shape=weibull_shape, scale=weibull_scale)*alpha_max
+        p_hat    <- ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
+        alpha_discount <- pweibull(p_hat, shape=weibull_shape, scale=weibull_scale)*alpha_max
       }
     }
   }
@@ -549,12 +605,12 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
   if(!arm2){
     posterior_survival <- 1-ppexp(q=surv_time, x=posterior_hazard, cuts=c(0,breaks))
   } else{
-    posterior_survival <- NULL
+    posterior_survival <- posterior_flat_survival <- prior_survival <- NULL
   }
 
 
   return(list(alpha_discount          = alpha_discount,
-              p_hat                   = p_test,
+              p_hat                   = p_hat,
               posterior_survival      = posterior_survival,
               posterior_flat_survival = posterior_flat_survival,
               prior_survival          = prior_survival,
@@ -563,63 +619,3 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
               prior_hazard            = prior_hazard))
 }
 
-
-
-
-
-### Create final result class
-final_survival <- function(posterior_treatment, posterior_control, arm2=FALSE,
-                           surv_time, breaks){
-
-
-  ### Two-arm trial densities only
-  if(!is.null(posterior_control) & arm2){
-    ### Finalize below code
-    density_post_control  <- density(posterior_control$posterior$posterior,
-                                     adjust = 0.5)
-    density_flat_control  <- density(posterior_control$posterior_flat,
-                                     adjust = 0.5)
-    density_prior_control <- density(posterior_control$prior,
-                                     adjust = 0.5)
-
-    ### Posterior hazard ratios at each interval
-    R0     <- log(posterior_treatment$posterior$posterior)-log(posterior_control$posterior$posterior)
-    V0     <- 1/apply(R0,2,var)
-    logHR0 <- R0%*%V0/sum(V0)
-
-    treatmentpost <- logHR0
-
-    return(list(density_post_control    = density_post_control,
-                density_flat_control    = density_flat_control,
-                density_prior_control   = density_prior_control,
-                treatmentpost           = treatmentpost))
-  }
-}
-
-
-### Transform posterior hazard density list into a data frame
-hazard_list_to_df <- function(hazard, starts, information_sources, group){
-  if(!is.list(hazard)){
-    return(hazard)
-  }
-
-  nS <- length(starts)
-  options(warn=-1)
-  df <- data.frame(information_sources = information_sources,
-                   group = group,
-                   start = starts[1],
-                   x = hazard[[1]]$x,
-                   y = hazard[[1]]$y)
-
-  for(i in 2:nS){
-    df1 <- data.frame(information_sources = information_sources,
-                      group = group,
-                      start = starts[i],
-                      x = hazard[[i]]$x,
-                      y = hazard[[i]]$y)
-    df <- rbind(df, df1)
-  }
-  options(warn=0)
-
-  return(df)
-}
