@@ -1,14 +1,28 @@
-#' @title plot
-#' @description normal plot method
+#' @title bdpnormal Object Plot
+#' @description \code{plot} method for class \code{bdpnormal}.
+#' @param x object of class \code{bdpnormal}. The result of a call to the
+#'   \code{\link{bdpnormal}} function.
+#' @param type character. Optional. Select plot type to print.
+#'   Supports the following: "discount" gives the discount function;
+#'   "posteriors" gives the posterior plots of the event rates; and
+#'   "density" gives the augmented posterior density plot(s).  Leave NULL to
+#'   display all plots in sequence.
+#'
+#' @details The \code{plot} method for \code{bdpnormal} returns up to three
+#'   plots: (1) posterior density curves; (2) posterior density of the effect
+#'   of interest; and (3) the discount function. A call to \code{plot} that
+#'   omits the \code{type} input returns one plot at a time and prompts the
+#'   user to click the plot or press return to proceed to the next plot.
+#'   Otherwise, the user can specify a plot \code{type} to display the
+#'   requested plot.
+#'
 #' @import methods
 #' @importFrom utils head
 #' @importFrom ggplot2 aes_string ggtitle ylim guides guide_legend theme element_blank
 #' @importFrom graphics par
-#' @importFrom stats density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
-#' @param x Result
+#' @importFrom stats sd density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
 #' @export
-setMethod("plot", signature(x = "bdpnormal"), function(x){
-  f                   <- x$f1
+setMethod("plot", signature(x = "bdpnormal"), function(x, type=NULL){
   posterior_treatment <- x$posterior_treatment
   posterior_control   <- x$posterior_control
   two_side            <- x$args1$two_side
@@ -20,51 +34,59 @@ setMethod("plot", signature(x = "bdpnormal"), function(x){
 
   information_sources <- NULL
 
-  ### Create dataframes for plotting via ggplot2
+  ### Create data frames for plotting via ggplot2
   D1 <- D2 <- D3 <- D5 <- D6 <- NULL
 
   if (arm2){
+    dens1 <- density(posterior_control$posterior_mu,
+                     adjust=0.5)
     D1 <- data.frame(information_sources="Posterior",
                      group="Control",
-                     y=f$density_post_control$y,
-                     x=f$density_post_control$x)
+                     x=dens1$x,
+                     y=dens1$y)
 
-    if(!is.null(f$density_flat_control)){
+    if(!is.null(posterior_control$posterior_flat_mu)){
+      dens2 <- density(posterior_control$posterior_flat_mu,adjust=0.5)
       D2 <- data.frame(information_sources="Current Data",
                        group="Control",
-                       y=f$density_flat_control$y,
-                       x=f$density_flat_control$x)
+                       x=dens2$x,
+                       y=dens2$y)
     }
 
-    if(!is.null(f$density_prior_control)){
+    if(!is.null(posterior_control$prior_mu)){
+      dens3 <- density(posterior_control$prior_mu,adjust=0.5)
       D3 <- data.frame(information_sources="Historical Data",
                        group="Control",
-                       y=f$density_prior_control$y,
-                       x=f$density_prior_control$x)
+                       x=dens3$x,
+                       y=dens3$y)
     }
   }
 
+
+  dens4 <- density(posterior_treatment$posterior_mu,adjust=0.5)
   D4 <- data.frame(information_sources="Posterior",
                    group="Treatment",
-                   y=f$density_post_treatment$y,
-                   x=f$density_post_treatment$x)
+                   x=dens4$x,
+                   y=dens4$y)
 
 
-  if(!is.null(f$density_flat_treatment)){
+  if(!is.null(posterior_treatment$posterior_flat_mu)){
+    dens5 <- density(posterior_treatment$posterior_flat_mu,adjust=0.5)
     D5 <- data.frame(information_sources="Current Data",
                      group="Treatment",
-                     y=f$density_flat_treatment$y,
-                     x=f$density_flat_treatment$x)
+                     x=dens5$x,
+                     y=dens5$y)
   }
 
-  if(!is.null(f$density_prior_treatment)){
+  if(!is.null(posterior_treatment$prior_mu)){
+    dens6 <- density(posterior_treatment$prior_mu,adjust=0.5)
     D6 <- data.frame(information_sources="Historical Data",
                      group="Treatment",
-                     y=f$density_prior_treatment$y,
-                     x=f$density_prior_treatment$x)
+                     x=dens6$x,
+                     y=dens6$y)
   }
 
-  D <- as.data.frame(rbind(D1,D2,D3,D4,D5,D6))
+  D <- rbind(D1,D2,D3,D4,D5,D6)
 
   D$information_sources <- factor(D$information_sources,
                                   levels = (c("Posterior","Current Data","Historical Data")))
@@ -167,27 +189,52 @@ setMethod("plot", signature(x = "bdpnormal"), function(x){
       theme(legend.title=element_blank())
   }
 
-  op <- par(ask=TRUE)
-  plot(post_typeplot)
-  plot(densityplot)
-  if(!is.null(discountfun_plot)){
-    plot(discountfun_plot)
+
+  if(is.null(type)){
+    op <- par(ask=TRUE)
+    plot(post_typeplot)
+    plot(densityplot)
+    if(!is.null(discountfun_plot)){
+      plot(discountfun_plot)
+    }
+    par(op)
+  } else if (type=="discount"){
+    if(!is.null(discountfun_plot)){
+      plot(discountfun_plot)
+    }
+  } else if (type=="posteriors"){
+    plot(post_typeplot)
+  } else if (type=="density"){
+    plot(densityplot)
   }
-  par(op)
 })
 
 
-#' @title plot
-#' @description binomial plot method
+#' @title bdpbinomial Object Plot
+#' @description \code{plot} method for class \code{bdpbinomial}.
+#' @param x object of class \code{bdpbinomial}. The result of a call to the
+#'   \code{\link{bdpbinomial}} function.
+#' @param type character. Optional. Select plot type to print.
+#'   Supports the following: "discount" gives the discount function;
+#'   "posteriors" gives the posterior plots of the event rates; and
+#'   "density" gives the augmented posterior density plot(s).  Leave NULL to
+#'   display all plots in sequence.
+#'
+#' @details The \code{plot} method for \code{bdpbinomial} returns up to three
+#'   plots: (1) posterior density curves; (2) posterior density of the effect
+#'   of interest; and (3) the discount function. A call to \code{plot} that
+#'   omits the \code{type} input returns one plot at a time and prompts the
+#'   user to click the plot or press return to proceed to the next plot.
+#'   Otherwise, the user can specify a plot \code{type} to display the
+#'   requested plot.
+#'
 #' @import methods
 #' @importFrom utils head
 #' @importFrom ggplot2 aes_string ggtitle ylim guides guide_legend theme element_blank
 #' @importFrom graphics par
 #' @importFrom stats density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
-#' @param x Result
 #' @export
-setMethod("plot", signature(x = "bdpbinomial"), function(x){
-  f                   <- x$f1
+setMethod("plot", signature(x = "bdpbinomial"), function(x, type=NULL){
   posterior_treatment <- x$posterior_treatment
   posterior_control   <- x$posterior_control
   two_side            <- x$args1$two_side
@@ -199,50 +246,59 @@ setMethod("plot", signature(x = "bdpbinomial"), function(x){
 
   information_sources <- NULL
 
-  ### Create dataframes for plotting via ggplot2
+  ### Create data frames for plotting via ggplot2
   D1 <- D2 <- D3 <- D5 <- D6 <- NULL
 
-  if(arm2){
-    D1 <- data.frame(information_sources='Posterior',
+  if (arm2){
+    dens1 <- density(posterior_control$posterior,
+                     adjust=0.5)
+    D1 <- data.frame(information_sources="Posterior",
                      group="Control",
-                     y=f$density_post_control$y,
-                     x=f$density_post_control$x)
+                     x=dens1$x,
+                     y=dens1$y)
 
-    if(!is.null(f$density_flat_control)){
+    if(!is.null(posterior_control$posterior_flat)){
+      dens2 <- density(posterior_control$posterior_flat,adjust=0.5)
       D2 <- data.frame(information_sources="Current Data",
                        group="Control",
-                       y=f$density_flat_control$y,
-                       x=f$density_flat_control$x)
+                       x=dens2$x,
+                       y=dens2$y)
     }
 
-    if(!is.null(f$density_prior_control)){
+    if(!is.null(posterior_control$prior)){
+      dens3 <- density(posterior_control$prior,adjust=0.5)
       D3 <- data.frame(information_sources="Historical Data",
                        group="Control",
-                       y=f$density_prior_control$y,
-                       x=f$density_prior_control$x)
+                       x=dens3$x,
+                       y=dens3$y)
     }
   }
 
-  D4 <- data.frame(information_sources='Posterior',
-                   group="Treatment",
-                   y=f$density_post_treatment$y,
-                   x=f$density_post_treatment$x)
 
-  if(!is.null(f$density_flat_treatment)){
+  dens4 <- density(posterior_treatment$posterior,adjust=0.5)
+  D4 <- data.frame(information_sources="Posterior",
+                   group="Treatment",
+                   x=dens4$x,
+                   y=dens4$y)
+
+
+  if(!is.null(posterior_treatment$posterior_flat)){
+    dens5 <- density(posterior_treatment$posterior_flat,adjust=0.5)
     D5 <- data.frame(information_sources="Current Data",
                      group="Treatment",
-                     y=f$density_flat_treatment$y,
-                     x=f$density_flat_treatment$x)
+                     x=dens5$x,
+                     y=dens5$y)
   }
 
-  if(!is.null(f$density_prior_treatment)){
+  if(!is.null(posterior_treatment$prior)){
+    dens6 <- density(posterior_treatment$prior,adjust=0.5)
     D6 <- data.frame(information_sources="Historical Data",
                      group="Treatment",
-                     y=f$density_prior_treatment$y,
-                     x=f$density_prior_treatment$x)
+                     x=dens6$x,
+                     y=dens6$y)
   }
 
-  D <- as.data.frame(rbind(D1,D2,D3,D4,D5,D6))
+  D <- rbind(D1,D2,D3,D4,D5,D6)
 
   D$information_sources <- factor(D$information_sources,
                                   levels = (c("Posterior","Current Data","Historical Data")))
@@ -345,28 +401,51 @@ setMethod("plot", signature(x = "bdpbinomial"), function(x){
   }
 
 
-  op <- par(ask=TRUE)
-  plot(post_typeplot)
-  plot(densityplot)
-  if(!is.null(discountfun_plot)){
-    plot(discountfun_plot)
+  if(is.null(type)){
+    op <- par(ask=TRUE)
+    plot(post_typeplot)
+    plot(densityplot)
+    if(!is.null(discountfun_plot)){
+      plot(discountfun_plot)
+    }
+    par(op)
+  } else if (type=="discount"){
+    if(!is.null(discountfun_plot)){
+      plot(discountfun_plot)
+    }
+  } else if (type=="posteriors"){
+    plot(post_typeplot)
+  } else if (type=="density"){
+    plot(densityplot)
   }
-  par(op)
+
+
 })
 
 
-#' @title plot
-#' @description survival plot method
+#' @title bdpsurvival Object Plot
+#' @description \code{plot} method for class \code{bdpsurvival}.
+#' @param x object of class \code{bdpsurvival}. The result of a call to the
+#'   \code{\link{bdpsurvival}} function.
+#' @param type character. Optional. Select plot type to print.
+#'   Supports the following: "discount" gives the discount function and
+#'   "survival" gives the survival curves.  Leave NULL to
+#'   display all plots in sequence.
+#'
+#' @details The \code{plot} method for \code{bdpsurvival} returns up to two
+#'   plots: (1) posterior survival curves and (2) the discount function. A
+#'   call to \code{plot} that omits the \code{type} input returns one plot
+#'   at a time and prompts the user to click the plot or press return to
+#'   proceed to the next plot. Otherwise, the user can specify a plot
+#'   \code{type} to display the requested plot.
+#'
 #' @import methods
 #' @importFrom utils head
 #' @importFrom ggplot2 aes_string ggtitle ylim guides guide_legend theme element_blank
 #' @importFrom graphics par
 #' @importFrom stats density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
-#' @param x Result
 #' @export
-setMethod("plot", signature(x = "bdpsurvival"), function(x){
-
-
+setMethod("plot", signature(x = "bdpsurvival"), function(x, type=NULL){
   args1               <- x$args1
   posterior_treatment <- x$posterior_treatment
   posterior_control   <- x$posterior_control
@@ -379,56 +458,113 @@ setMethod("plot", signature(x = "bdpsurvival"), function(x){
   ### Survival curve(s)
   ### - Only computed for one-arm trial
   ##############################################################################
-  if(!arm2){
-    ### Organize data for current treatment
-    time_t  <- sort(unique(args1$S_t$time))
-    survival_times_posterior_flat <- lapply(time_t, ppexp,
-      posterior_treatment$posterior_flat_hazard, cuts=c(0,breaks))
+  ### Organize data for current treatment
+  time_t  <- sort(unique(args1$S_t$time))
+  survival_times_posterior_flat <- lapply(time_t, ppexp,
+    posterior_treatment$posterior_flat_hazard, cuts=c(0,breaks))
+  survival_median_posterior_flat <- 1-sapply(survival_times_posterior_flat, median)
+
+  D1 <- data.frame(source  = "Current Data",
+                   group = "Treatment",
+                   x      = time_t,
+                   y      = survival_median_posterior_flat)
+
+  ### Organize data for historical treatment
+  if(!is.null(args1$S0_t)){
+    time0_t <- sort(unique(args1$S0_t$time))
+    survival_times_prior <- lapply(time0_t, ppexp,
+      posterior_treatment$prior_hazard, cuts=c(0,breaks))
+    survival_median_prior <- 1-sapply(survival_times_prior, median)
+
+    D2 <- data.frame(source = "Historical Data",
+                     group  = "Treatment",
+                     x      = time0_t,
+                     y      = survival_median_prior)
+  } else{
+    D2 <- NULL
+  }
+
+  ### Organize data for treatment posterior
+  survival_times_posterior  <- lapply(time_t, ppexp,posterior_treatment$posterior_hazard,cuts=c(0,breaks))
+  survival_median_posterior <- 1-sapply(survival_times_posterior, median)
+
+  D3 <- data.frame(source = "Posterior",
+                   group  = "Treatment",
+                   x      = time_t,
+                   y      = survival_median_posterior)
+
+  ### Organize data for current control
+  if(!is.null(args1$S_c)){
+    time_c               <- sort(unique(args1$S_c$time))
+    survival_times_posterior_flat <- lapply(time_c, ppexp,
+                                           posterior_control$posterior_flat_hazard, cuts=c(0,breaks))
     survival_median_posterior_flat <- 1-sapply(survival_times_posterior_flat, median)
 
-    D1 <- data.frame(source  = "Current Data",
-                     group = "Treatment",
-                     x      = time_t,
+    D4 <- data.frame(source = "Current Data",
+                     group  = "Control",
+                     x      = time_c,
                      y      = survival_median_posterior_flat)
+  } else{
+    D4 <- NULL
+  }
 
-    ### Organize data for historical treatment
-    if(!is.null(args1$S0_t)){
-      time0_t <- sort(unique(args1$S0_t$time))
-      survival_times_prior <- lapply(time0_t, ppexp,
-        posterior_treatment$prior_hazard, cuts=c(0,breaks))
-      survival_median_prior <- 1-sapply(survival_times_prior, median)
+  ### Organize data for historical control
+  if(!is.null(args1$S0_c)){
+    time0_c               <- sort(unique(args1$S0_c$time))
+    survival_times_prior <- lapply(time0_c, ppexp,
+                                   posterior_control$prior_hazard, cuts=c(0,breaks))
+    survival_median_prior <- 1-sapply(survival_times_prior, median)
 
-      D2 <- data.frame(source = "Historical Data",
-                       group  = "Treatment",
-                       x      = time0_t,
-                       y      = survival_median_prior)
-    } else{
-      D2 <- NULL
-    }
+    D5 <- data.frame(source = "Historical Data",
+                     group  = "Control",
+                     x      = time0_c,
+                     y      = survival_median_prior)
+  } else{
+    D5 <- NULL
+  }
 
-    ### Organize data for posterior
-    survival_times_posterior  <- lapply(time_t, ppexp,posterior_treatment$posterior_hazard,cuts=c(0,breaks))
+  ### Organize data for control posterior
+  if(!is.null(args1$S_c) & !is.null(args1$S0_c)){
+    survival_times_posterior  <- lapply(time_c, ppexp,posterior_control$posterior_hazard,cuts=c(0,breaks))
     survival_median_posterior <- 1-sapply(survival_times_posterior, median)
 
-    D3 <- data.frame(source = "Posterior",
-                     group  = "Treatment",
-                     x      = time_t,
+    D6 <- data.frame(source = "Posterior",
+                     group  = "Control",
+                     x      = time_c,
                      y      = survival_median_posterior)
+  } else if(is.null(args1$S_c) & !is.null(args1$S0_c)){
+    survival_times_posterior  <- lapply(time0_c, ppexp,posterior_control$posterior_hazard,cuts=c(0,breaks))
+    survival_median_posterior <- 1-sapply(survival_times_posterior, median)
 
-    D <- rbind(D1,D2,D3)
+    D6 <- data.frame(source = "Posterior",
+                     group  = "Control",
+                     x      = time0_c,
+                     y      = survival_median_posterior)
+  } else if(!is.null(args1$S_c) & is.null(args1$S0_c)){
+    survival_times_posterior  <- lapply(time_c, ppexp,posterior_control$posterior_hazard,cuts=c(0,breaks))
+    survival_median_posterior <- 1-sapply(survival_times_posterior, median)
 
-
-    ### Plot survival curve
-    survival_curves <- ggplot(D, aes_string(x = "x", y = "y")) +
-      geom_line(size=1.4, aes_string(color="source", lty="source")) +
-      ylab("Survival probability") +
-      xlab("Time") +
-      theme_bw() +
-      ggtitle("Survival Curve(s)") +
-      guides(fill=guide_legend(title=NULL)) +
-      theme(legend.title=element_blank())
+    D6 <- data.frame(source = "Posterior",
+                     group  = "Control",
+                     x      = time_c,
+                     y      = survival_median_posterior)
+  } else{
+    D6 <- NULL
   }
 
+  D <- rbind(D4,D5,D6, D1,D2,D3)
+
+  ### Plot survival curve
+  survival_curves <- ggplot(D, aes_string(x="x",y="y")) +
+    geom_line(size=1.4, aes_string(color="source", lty="source")) +
+    facet_wrap(~group, ncol=1,scales='free') +
+    ylab("Survival probability") +
+    xlab("Time") +
+    theme_bw() +
+    ggtitle("Survival Curve(s)") +
+    guides(fill=guide_legend(title=NULL)) +
+    theme(legend.title=element_blank())
+
 
   ##############################################################################
   ### Discount function plot
@@ -498,15 +634,22 @@ setMethod("plot", signature(x = "bdpsurvival"), function(x){
   }
 
 
-  if(!arm2){
+  if(is.null(type)){
     op <- par(ask=TRUE)
     plot(survival_curves)
-    if(!is.null(args1$S0_t)){
+    if(!is.null(args1$S0_t) | (!is.null(args1$S_c) & !is.null(args1$S0_c))){
       plot(discountfun_plot)
     }
     par(op)
+  } else if(type=="discount"){
+    if(!is.null(args1$S0_t) | (!is.null(args1$S_c) & !is.null(args1$S0_c))){
+      plot(discountfun_plot)
+    }
+  } else if(type=="survival"){
+    plot(survival_curves)
   }
 
+
 })
 
 
